# Wirepas Mesh Messaging

This wheel contains the generated code to interact with Wirepas Mesh Network
 through the Gateway to Backend API.

## Installation

### Install from PyPi

This package is available from [PyPi][pypi].

```shell
    pip install wirepas-mesh-messaging
```

### From the source


## Services API documentation

Please refer to the [backend apis repository][github_backend_apis] for
documentation on the Wirepas' services APIs.


## License

Licensed under the Apache License, Version 2.0.
See [LICENSE][here_license] for the full license text.

[pypi]: https://pypi.org/project/wirepas-messaging/

[github_backend_apis]: https://github.com/wirepas/backend-apis
